@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -43,7 +43,7 @@ void *Arithc(void *argument)
   int varID, levelID;
   int vlistID1, vlistID2;
   double rconst;
-  FIELD field;
+  field_t field;
   int taxisID1, taxisID2;
 
   cdoInitialize(argument);
@@ -69,9 +69,6 @@ void *Arithc(void *argument)
   taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  if ( operfunc == func_mul || operfunc == func_div )
-    nospec(vlistID1);
-
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
   if ( streamID2 < 0 ) cdiError(streamID2, "Open failed on %s", cdoStreamName(1));
 
