@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -27,10 +27,6 @@
       Change     chltype         Change GRIB level type 
 */
 
-
-#include <string.h>
-#include <math.h>   /* fabs */
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
