@@ -21,10 +21,6 @@
       Hi      hi           Compute the humidity index
 */
 
-
-#include <string.h>
-#include <math.h>
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
