@@ -22,10 +22,6 @@
       Intgrid    intgridbil      Bilinear grid interpolation
 */
 
-
-#include <string.h>
-#include <math.h>
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
