@@ -35,10 +35,6 @@
       Remap       remap           SCRIP grid remapping
 */
 
-
-#include <string.h>
-#include <math.h>
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
