@@ -4,7 +4,6 @@
 
   Copyright (C) 2007-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
-
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.
@@ -21,10 +20,7 @@
       Remapeta     remapeta          Model to model level interpolation
 */
 
-
 #include <ctype.h>
-#include <string.h>
-#include <math.h>
 
 #include "cdi.h"
 #include "cdo.h"
@@ -33,22 +29,7 @@
 #include "functs.h"
 #include "vinterp.h"
 #include "list.h"
-
-#include <math.h>
-#include <stdlib.h>
-#include <stdio.h>
-
-
-void hetaeta(int ltq, int ngp, const int *imiss,
-	     int nlev1, const double * restrict ah1, const double * restrict bh1,
-             const double * restrict fis1, const double * restrict ps1, 
-             const double * restrict t1, const double * restrict q1,
-             int nlev2, const double * restrict ah2, const double * restrict bh2, 
-             const double * restrict fis2, double * restrict ps2, 
-             double * restrict t2, double * restrict q2,
-	     int nvars, double ** restrict vars1, double ** restrict vars2,
-	     double * restrict tscor, double * restrict pscor,
-	     double * restrict secor);
+#include "hetaeta.h"
 
 
 static 
@@ -266,6 +247,7 @@ void *Remapeta(void *argument)
   int lfis2 = FALSE;
   int varids[MAX_VARS3D];
   int *imiss = NULL;
+  int timer_hetaeta = 0;
   long nctop;
   double *array = NULL;
   double *deltap1 = NULL, *deltap2 = NULL;
@@ -281,6 +263,8 @@ void *Remapeta(void *argument)
   double cconst = 1.E-6;
   const char *fname;
 
+  if ( cdoTimer ) timer_hetaeta = timer_new("Remapeta_hetaeta");
+
   cdoInitialize(argument);
 
   REMAPETA  = cdoOperatorAdd("remapeta",   0, 0, "VCT file name");
@@ -301,7 +285,7 @@ void *Remapeta(void *argument)
 
       if ( cdoVerbose )
 	for ( i = 0; i < nlevh2+1; ++i )
-	  fprintf(stdout, "vct2: %5d %25.17f %25.17f\n", i, vct2[i], vct2[nvct2/2+i]);
+	  cdoPrint("vct2: %5d %25.17f %25.17f", i, vct2[i], vct2[nvct2/2+i]);
 
       if ( operatorArgc() == 2 )
 	{
@@ -399,6 +383,10 @@ void *Remapeta(void *argument)
 
   nzaxis  = vlistNzaxis(vlistID1);
   lhavevct = FALSE;
+
+  if ( cdoVerbose )
+    cdoPrint("nzaxis: %d", nzaxis);
+
   for ( i = 0; i < nzaxis; i++ )
     {
       zaxisID = vlistZaxis(vlistID1, i);
@@ -408,6 +396,10 @@ void *Remapeta(void *argument)
 	  if ( nlevel > 1 )
 	    {
 	      nvct1 = zaxisInqVctSize(zaxisID);
+
+              if ( cdoVerbose )
+                cdoPrint("i: %d, vct1 size of zaxisID %d = %d", i, zaxisID, nvct1);
+
 	      if ( nlevel == (nvct1/2 - 1) )
 		{
 		  if ( lhavevct == FALSE )
@@ -416,6 +408,9 @@ void *Remapeta(void *argument)
 		      zaxisIDh = zaxisID;
 		      nlevh1   = nlevel;
 	      
+                      if ( cdoVerbose )
+                        cdoPrint("lhavevct=TRUE  zaxisIDh = %d, nlevh1   = %d", zaxisIDh, nlevel);
+ 
 		      vct1 = (double *) malloc(nvct1*sizeof(double));
 		      memcpy(vct1, zaxisInqVctPtr(zaxisID), nvct1*sizeof(double));
 		      
@@ -425,7 +420,7 @@ void *Remapeta(void *argument)
 		      b1 = vct1 + nvct1/2;
 		      if ( cdoVerbose )
 			for ( i = 0; i < nvct1/2; ++i )
-			  fprintf(stdout, "vct1: %5d %25.17f %25.17f\n", i, vct1[i], vct1[nvct1/2+i]);
+			  cdoPrint("vct1: %5d %25.17f %25.17f", i, vct1[i], vct1[nvct1/2+i]);
 		    }
 		  else
 		    {
@@ -433,12 +428,22 @@ void *Remapeta(void *argument)
 			vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
 		    }
 		}
+              else 
+                {
+		  if ( cdoVerbose )
+		    cdoPrint("nlevel /= (nvct1/2 - 1): nlevel = %d", nlevel);
+                }
 	    }
 	  else
 	    {
 	      vlistChangeZaxisIndex(vlistID2, i, surfaceID);
 	    }
 	}
+      else
+        {
+	  if ( cdoVerbose )
+	    cdoPrint("i: %d, type of zaxisID %d not ZAXIS_HYBRID", i, zaxisID);
+        }
     }
 
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
@@ -566,7 +571,9 @@ void *Remapeta(void *argument)
 
   if ( zaxisIDh != -1 && geopID == -1 )
     {
-      cdoWarning("Orography (geosp) not found - using zero orography!");
+      if ( ltq )
+	cdoWarning("Orography (geosp) not found - using zero orography!");
+
       memset(fis1, 0, ngp*sizeof(double));
     }
 
@@ -694,15 +701,19 @@ void *Remapeta(void *argument)
 	}
 
       if ( nvars3D || ltq )
-	hetaeta(ltq, ngp, imiss,
-		nlevh1, a1, b1,
-		fis1, ps1,
-		t1, q1,
-		nlevh2, a2, b2,
-		fis2, ps2,
-		t2, q2,
-		nvars3D, vars1, vars2,
-		tscor, pscor, secor);
+	{
+	  if ( cdoTimer ) timer_start(timer_hetaeta);
+	  hetaeta(ltq, ngp, imiss,
+		  nlevh1, a1, b1,
+		  fis1, ps1,
+		  t1, q1,
+		  nlevh2, a2, b2,
+		  fis2, ps2,
+		  t2, q2,
+		  nvars3D, vars1, vars2,
+		  tscor, pscor, secor);
+	  if ( cdoTimer ) timer_stop(timer_hetaeta);
+	}
 
       nctop = ncctop((long) nlevh2, (long) nlevh2+1, a2, b2);
 
