@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,7 @@
 /*
    This module contains the following operators:
 
+      Showinfo   showparam       Show parameters
       Showinfo   showcode        Show code numbers
       Showinfo   showname        Show variable names
       Showinfo   showstdname     Show variable standard names
@@ -40,7 +41,8 @@
 
 void *Showinfo(void *argument)
 {
-  int SHOWYEAR, SHOWMON, SHOWDATE, SHOWTIME, SHOWCODE, SHOWNAME, SHOWSTDNAME, SHOWLEVEL, SHOWLTYPE, SHOWFORMAT;
+  int SHOWYEAR, SHOWMON, SHOWDATE, SHOWTIME, SHOWTIMESTAMP, SHOWCODE;
+  int SHOWPARAM, SHOWNAME, SHOWSTDNAME, SHOWLEVEL, SHOWLTYPE, SHOWFORMAT;
   int operatorID;
   int varID, zaxisID;
   int vdate, vtime;
@@ -52,23 +54,26 @@ void *Showinfo(void *argument)
   int taxisID;
   int streamID;
   int vlistID;
-  int year, month, day, hour, minute, second;
+  int year, month, day;
   int month0 = 0, nmonth, year0 = 0, nyear;
   char varname[256];
   char stdname[256];
+  char vdatestr[32], vtimestr[32];
 
   cdoInitialize(argument);
 
-  SHOWYEAR    = cdoOperatorAdd("showyear",      0, 0, NULL);
-  SHOWMON     = cdoOperatorAdd("showmon",       0, 0, NULL);
-  SHOWDATE    = cdoOperatorAdd("showdate",      0, 0, NULL);
-  SHOWTIME    = cdoOperatorAdd("showtime",      0, 0, NULL);
-  SHOWCODE    = cdoOperatorAdd("showcode",      0, 0, NULL);
-  SHOWNAME    = cdoOperatorAdd("showname",      0, 0, NULL);
-  SHOWSTDNAME = cdoOperatorAdd("showstdname",   0, 0, NULL);
-  SHOWLEVEL   = cdoOperatorAdd("showlevel",     0, 0, NULL);
-  SHOWLTYPE   = cdoOperatorAdd("showltype",     0, 0, NULL);
-  SHOWFORMAT  = cdoOperatorAdd("showformat",    0, 0, NULL);
+  SHOWYEAR      = cdoOperatorAdd("showyear",      0, 0, NULL);
+  SHOWMON       = cdoOperatorAdd("showmon",       0, 0, NULL);
+  SHOWDATE      = cdoOperatorAdd("showdate",      0, 0, NULL);
+  SHOWTIME      = cdoOperatorAdd("showtime",      0, 0, NULL);
+  SHOWTIMESTAMP = cdoOperatorAdd("showtimestamp", 0, 0, NULL);
+  SHOWCODE      = cdoOperatorAdd("showcode",      0, 0, NULL);
+  SHOWPARAM     = cdoOperatorAdd("showparam",     0, 0, NULL);
+  SHOWNAME      = cdoOperatorAdd("showname",      0, 0, NULL);
+  SHOWSTDNAME   = cdoOperatorAdd("showstdname",   0, 0, NULL);
+  SHOWLEVEL     = cdoOperatorAdd("showlevel",     0, 0, NULL);
+  SHOWLTYPE     = cdoOperatorAdd("showltype",     0, 0, NULL);
+  SHOWFORMAT    = cdoOperatorAdd("showformat",    0, 0, NULL);
 
   operatorID = cdoOperatorID();
 
@@ -90,7 +95,7 @@ void *Showinfo(void *argument)
 	  {
 	    vdate = taxisInqVdate(taxisID);
 
-	    decode_date(vdate, &year, &month, &day);
+	    cdiDecodeDate(vdate, &year, &month, &day);
 	 
 	    if ( tsID == 0 || year0 != year )
 	      {
@@ -113,7 +118,7 @@ void *Showinfo(void *argument)
 	  {
 	    vdate = taxisInqVdate(taxisID);
 
-	    decode_date(vdate, &year, &month, &day);
+	    cdiDecodeDate(vdate, &year, &month, &day);
 	 
 	    if ( tsID == 0 || month0 != month )
 	      {
@@ -136,13 +141,13 @@ void *Showinfo(void *argument)
 	  {
 	    vdate = taxisInqVdate(taxisID);
 	 
-	    decode_date(vdate, &year, &month, &day);
+	    date2str(vdate, vdatestr, sizeof(vdatestr));
 
 	    if ( tsID == 0 || date0 != vdate )
 	      {
 		/* if ( ndate == 10 ) { ndate = 0; fprintf(stdout, "\n"); } */
 		date0 = vdate;
-		fprintf(stdout, " "DATE_FORMAT, year, month, day);
+		fprintf(stdout, " %s", vdatestr);
 		ndate++;
 	      }
 
@@ -151,6 +156,24 @@ void *Showinfo(void *argument)
       fprintf(stdout, "\n");
     }
   else if ( operatorID == SHOWTIME )
+    {
+      nout = 0;
+      tsID = 0;
+      if ( ntsteps != 0 )
+	while ( (nrecs = streamInqTimestep(streamID, tsID)) )
+	  {
+	    /* if ( nout == 4 ) { nout = 0; fprintf(stdout, "\n"); } */
+	    vtime = taxisInqVtime(taxisID);
+
+	    time2str(vtime, vtimestr, sizeof(vtimestr));
+	    fprintf(stdout, " %s", vtimestr);
+
+	    tsID++;
+	    nout++;
+	  }
+      fprintf(stdout, "\n");
+    }
+  else if ( operatorID == SHOWTIMESTAMP )
     {
       nout = 0;
       tsID = 0;
@@ -161,11 +184,10 @@ void *Showinfo(void *argument)
 	    vdate = taxisInqVdate(taxisID);
 	    vtime = taxisInqVtime(taxisID);
 
-	    decode_date(vdate, &year, &month, &day);
-	    decode_time(vtime, &hour, &minute, &second);
+	    date2str(vdate, vdatestr, sizeof(vdatestr));
+	    time2str(vtime, vtimestr, sizeof(vtimestr));
+	    fprintf(stdout, " %sT%s", vdatestr, vtimestr);
 
-	    fprintf(stdout, " "DATE_FORMAT" "TIME_FORMAT,
-		    year, month, day, hour, minute, second);
 	    tsID++;
 	    nout++;
 	  }
@@ -182,6 +204,20 @@ void *Showinfo(void *argument)
 	}
       fprintf(stdout, "\n");
     }
+  else if ( operatorID == SHOWPARAM )
+    {
+      int param;
+      char paramstr[32];
+      
+      for ( varID = 0; varID < nvars; varID++ )
+	{
+	  param   = vlistInqVarParam(vlistID, varID);
+	  cdiParamToString(param, paramstr, sizeof(paramstr));
+
+	  fprintf(stdout, " %s", paramstr);
+	}
+      fprintf(stdout, "\n");
+    }
   else if ( operatorID == SHOWNAME )
     {
       for ( varID = 0; varID < nvars; varID++ )
