@@ -21,11 +21,8 @@
       Specinfo specinfo  Spectral information
 */
 
-
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
-#include <math.h>
+
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
