@@ -22,10 +22,6 @@
       Vardup     parmul          Multiply parameters
 */
 
-
-#include <string.h>
-#include <math.h>
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
