@@ -21,10 +21,7 @@
       Vertwind    vertwind      Convert the vertical velocity to [m/s]
 */
 
-
 #include <ctype.h>
-#include <string.h>
-#include <math.h>
 
 #include "cdi.h"
 #include "cdo.h"
