@@ -27,11 +27,6 @@
       Ydrunstat    ydrunstd          Multi-year daily running standard deviation
 */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <math.h>
-
 #include "cdi.h"
 #include "cdo.h"
 #include "cdo_int.h"
