@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@ void *Zonstat(void *argument)
   int operfunc;
   int streamID1, streamID2;
   int vlistID1, vlistID2;
-  int gridID1, gridID2;
+  int gridID1, gridID2 = -1;
   int nlatmax;
   int index, ngrids;
   int recID, nrecs;
@@ -52,7 +52,7 @@ void *Zonstat(void *argument)
   int lim;
   int ndiffgrids;
   int taxisID1, taxisID2;
-  FIELD field1, field2;
+  field_t field1, field2;
   /* RQ */
   int pn = 0;
   /* QR */
@@ -104,12 +104,18 @@ void *Zonstat(void *argument)
 
   index = 0;
   gridID1 = vlistGrid(vlistID1, index);
-  if ( gridInqType(gridID1) != GRID_LONLAT &&
-       gridInqType(gridID1) != GRID_GAUSSIAN &&
-       !(gridInqType(gridID1) == GRID_GENERIC && gridInqYsize(gridID1) <= 1) )
-    cdoAbort("Unsupported gridtype: %s", gridNamePtr(gridInqType(gridID1)));
 
-  gridID2 = gridToZonal(gridID1);
+  if ( gridInqType(gridID1) == GRID_LONLAT   ||
+       gridInqType(gridID1) == GRID_GAUSSIAN ||
+       gridInqType(gridID1) == GRID_GENERIC )
+    {
+      gridID2 = gridToZonal(gridID1);
+    }
+  else
+    {
+      cdoAbort("Unsupported gridtype: %s", gridNamePtr(gridInqType(gridID1)));
+    }
+
   for ( index = 0; index < ngrids; index++ )
     vlistChangeGridIndex(vlistID2, index, gridID2);
 
