@@ -100,7 +100,7 @@ void exp_run(int argc, char *argv[], char *cdoExpName);
 
 
 int timer_total, timer_read, timer_write;
-int timer_remap, timer_remap_con, timer_remap_con2, timer_remap_con3;
+int timer_remap, timer_remap_sort, timer_remap_con, timer_remap_con2, timer_remap_con3;
 
 
 #define PRINT_RLIMIT(resource) \
@@ -185,7 +185,7 @@ void usage(void)
   fprintf(stderr, "  Options:\n");
   fprintf(stderr, "    -a             Generate an absolute time axis\n");
   fprintf(stderr, "    -b <nbits>     Set the number of bits for the output precision\n");
-  fprintf(stderr, "                   (32/64 for nc/nc2/nc4/srv/ext/ieg; 1 - 32 for grb/grb2)\n");
+  fprintf(stderr, "                   (I8/I16/I32/F32/F64 for nc/nc2/nc4; F32/F64 for srv/ext/ieg; 1 - 32 for grb/grb2)\n");
   fprintf(stderr, "                   Add L or B to set the byteorder to Little or Big endian\n");
   fprintf(stderr, "    -f <format>    Format of the output file. (grb, grb2, nc, nc2, nc4, srv, ext or ieg)\n");
   fprintf(stderr, "    -g <grid>      Set default grid name or file. Available grids: \n");
@@ -1008,6 +1008,7 @@ int main(int argc, char *argv[])
 	  timer_read       = timer_new("read");
 	  timer_write      = timer_new("write");
 	  timer_remap      = timer_new("remap");
+	  timer_remap_sort = timer_new("remap sort");
 	  timer_remap_con  = timer_new("remap con");
 	  timer_remap_con2 = timer_new("remap con2");
 	  timer_remap_con3 = timer_new("remap con3");
