@@ -1385,92 +1385,6 @@ void gme_grid(int gridsize, double *rlon, double *rlat,
   free(xn);
 }
 
-
-double areas(struct cart *dv1, struct cart *dv2, struct cart *dv3)
-{
-  double a1, a2, a3;
-  double ca1, ca2, ca3;
-  double s12, s23, s31;
-
-  struct cart u12, u23, u31;
-
-  double areas;
-
-  /* compute cross products Uij = Vi X Vj */
-
-  u12.x[0] = dv1->x[1]*dv2->x[2] - dv1->x[2]*dv2->x[1];
-  u12.x[1] = dv1->x[2]*dv2->x[0] - dv1->x[0]*dv2->x[2];
-  u12.x[2] = dv1->x[0]*dv2->x[1] - dv1->x[1]*dv2->x[0];
-  
-  u23.x[0] = dv2->x[1]*dv3->x[2] - dv2->x[2]*dv3->x[1];
-  u23.x[1] = dv2->x[2]*dv3->x[0] - dv2->x[0]*dv3->x[2];
-  u23.x[2] = dv2->x[0]*dv3->x[1] - dv2->x[1]*dv3->x[0];
-  
-  u31.x[0] = dv3->x[1]*dv1->x[2] - dv3->x[2]*dv1->x[1];
-  u31.x[1] = dv3->x[2]*dv1->x[0] - dv3->x[0]*dv1->x[2];
-  u31.x[2] = dv3->x[0]*dv1->x[1] - dv3->x[1]*dv1->x[0];
-  
-  /* normalize Uij to unit vectors */
-  
-  s12 = u12.x[0]*u12.x[0]+u12.x[1]*u12.x[1]+u12.x[2]*u12.x[2];
-  s23 = u23.x[0]*u23.x[0]+u23.x[1]*u23.x[1]+u23.x[2]*u23.x[2];
-  s31 = u31.x[0]*u31.x[0]+u31.x[1]*u31.x[1]+u31.x[2]*u31.x[2];
-
-  /* test for a degenerate triangle associated with collinear vertices */
-  
-  if ( !(fabs(s12) > 0.0) || !(fabs(s23) > 0.0) || !(fabs(s31) > 0.0) ) {
-    areas = 0.0;
-    return areas;
-  }
-
-  s12 = sqrt(s12);
-  s23 = sqrt(s23);
-  s31 = sqrt(s31);
-  
-  u12.x[0] = u12.x[0]/s12; u12.x[1] = u12.x[1]/s12; u12.x[2] = u12.x[2]/s12;
-  u23.x[0] = u23.x[0]/s23; u23.x[1] = u23.x[1]/s23; u23.x[2] = u23.x[2]/s23;
-  u31.x[0] = u31.x[0]/s31; u31.x[1] = u31.x[1]/s31; u31.x[2] = u31.x[2]/s31;
-  
-  /*
-   *  Compute interior angles Ai as the dihedral angles between planes:
-   *  CA1 = cos(A1) = -<U12,U31>
-   *  CA2 = cos(A2) = -<U23,U12>
-   *  CA3 = cos(A3) = -<U31,U23>
-   */
-
-  ca1 = -( u12.x[0]*u31.x[0]+u12.x[1]*u31.x[1]+u12.x[2]*u31.x[2] );
-  ca2 = -( u23.x[0]*u12.x[0]+u23.x[1]*u12.x[1]+u23.x[2]*u12.x[2] );
-  ca3 = -( u31.x[0]*u23.x[0]+u31.x[1]*u23.x[1]+u31.x[2]*u23.x[2] );
-
-#if ! defined (FMAX)
-#define  FMAX(a,b)  ((a) > (b) ? (a) : (b))
-#endif
-#if ! defined (FMIN)
-#define  FMIN(a,b)  ((a) < (b) ? (a) : (b))
-#endif
-
-  ca1 = FMAX(ca1, -1.0);
-  ca1 = FMIN(ca1, +1.0);
-  ca2 = FMAX(ca2, -1.0);
-  ca2 = FMIN(ca2, +1.0);
-  ca3 = FMAX(ca3, -1.0);
-  ca3 = FMIN(ca3, +1.0);
-  
-  a1 = acos(ca1);
-  a2 = acos(ca2);
-  a3 = acos(ca3);
-  
-  /* compute AREAS = A1 + A2 + A3 - PI */
-  
-  areas = a1 + a2 + a3 - M_PI;
-
-  if ( areas < 0.0 ) {
-    areas = 0.0;
-  }
-
-  return areas;
-}
-
 /*
 int main(int argc, char *argv[])
 {
