@@ -47,12 +47,14 @@ void *CDItest(void *argument);
 void *Change(void *argument);
 void *Change_e5slm(void *argument);
 void *Cloudlayer(void *argument);
+void *Command(void *argument);
 void *Comp(void *argument);
 void *Compc(void *argument);
+void *Complextorect(void *argument);
 void *Cond(void *argument);
 void *Cond2(void *argument);
 void *Condc(void *argument);
-void *Complextorect(void *argument);
+void *Consecstat(void *argument);
 void *Copy(void *argument);
 void *Deltime(void *argument);
 void *Detrend(void *argument);
@@ -62,7 +64,7 @@ void *Enlarge(void *argument);
 void *Enlargegrid(void *argument);
 void *Ensstat(void *argument);
 void *Eofcoeff(void *argument);
-void *Timeof(void *argument);
+void *EOFs(void *argument);
 void *Expr(void *argument);
 void *Filedes(void *argument);
 void *Fillmiss(void *argument);
@@ -71,6 +73,7 @@ void *Fldrms(void *argument);
 void *Fldstat(void *argument);
 void *Fldstat2(void *argument);
 void *Fourier(void *argument);
+void *Gather(void *argument);
 void *Gengrid(void *argument);
 void *Gradsdes(void *argument);
 void *Gridboxstat(void *argument);
@@ -112,6 +115,7 @@ void *Regres(void *argument);
 void *Remap(void *argument);
 void *Remapeta(void *argument);
 void *Replace(void *argument);
+void *Replacevalues(void *argument);
 void *Rotuv(void *argument);
 void *Runpctl(void *argument);
 void *Runstat(void *argument);
@@ -130,10 +134,10 @@ void *Setgatt(void *argument);
 void *Setgrid(void *argument);
 void *Sethalo(void *argument);
 void *Setmiss(void *argument);
-void *Setrange(void *argument);
 void *Setrcaname(void *argument);
 void *Settime(void *argument);
 void *Setzaxis(void *argument);
+void *Scatter(void *argument);
 void *Showinfo(void *argument);
 void *Sinfo(void *argument);
 void *Smooth9(void *argument);
@@ -244,12 +248,14 @@ void *Wct(void *argument);
 #define  ChangeOperators        {"chcode", "chtabnum", "chname", "chlevel", "chlevelc", "chlevelv", "chltype"}
 #define  Change_e5slmOperators  {"change_e5slm", "change_e5lsm", "change_e5mask"}
 #define  CloudlayerOperators    {"cloudlayer"}
+#define  CommandOperators       {"command", "com", "cmd"}
 #define  CompOperators          {"eq",  "ne",  "le",  "lt",  "ge",  "gt"}
 #define  CompcOperators         {"eqc", "nec", "lec", "ltc", "gec", "gtc"}
+#define  ComplextorectOperators {"complextorect"}
 #define  CondOperators          {"ifthen",  "ifnotthen"}
 #define  Cond2Operators         {"ifthenelse"}
 #define  CondcOperators         {"ifthenc", "ifnotthenc"}
-#define  ComplextorectOperators {"complextorect"}
+#define  ConsecstatOperators    {"consects", "consecsum"}
 #define  CopyOperators          {"copy", "selall"}
 #define  DeltimeOperators       {"delday", "del29feb"}
 #define  DetrendOperators       {"detrend"}
@@ -260,7 +266,7 @@ void *Wct(void *argument);
 #define  EnlargegridOperators   {"enlargegrid"}
 #define  EnsstatOperators       {"ensmin", "ensmax", "enssum", "ensmean", "ensavg", "ensvar", "ensstd", "enspctl"}
 #define  EofcoeffOperators      {"eofcoeff"}
-#define  TimeofOperators        {"eof", "eofspatial", "eoftime"}
+#define  EOFsOperators          {"eof", "eofspatial", "eoftime"}
 #define  ExprOperators          {"expr", "exprf", "aexpr", "aexprf"}
 #define  FiledesOperators       {"filedes", "griddes", "griddes2", "zaxisdes", "vct", "vct2", "pardes", \
                                  "vlist", "partab", "partab2"}
@@ -270,6 +276,7 @@ void *Wct(void *argument);
 #define  FldstatOperators       {"fldmin", "fldmax", "fldsum", "fldmean", "fldavg", "fldvar", "fldstd", "fldpctl"}
 #define  Fldstat2Operators      {"fldcor"}
 #define  FourierOperators       {"fourier"}
+#define  GatherOperators        {"gather"}
 #define  GengridOperators       {"gengrid"}
 #define  GradsdesOperators      {"gradsdes1", "gradsdes2", "dumpmap"}
 #define  GridboxstatOperators   {"gridboxmin", "gridboxmax", "gridboxsum", "gridboxmean", "gridboxavg", \
@@ -320,6 +327,7 @@ void *Wct(void *argument);
 #define    GenweightsOperators  {"gencon", "genbil", "genbic", "gendis", "gennn", "genlaf", "gencon2"}
 #define  RemapetaOperators      {"remapeta", "remapeta_s", "remapeta_z"}
 #define  ReplaceOperators       {"replace"}
+#define  ReplacevaluesOperators {"setvals", "setrtoc", "setrtoc2"}
 #define  RotuvOperators         {"rotuvb"}
 #define  RunpctlOperators       {"runpctl"}
 #define  RunstatOperators       {"runmin",  "runmax",  "runsum",  "runmean",  "runavg",  "runvar",  "runstd"}
@@ -340,11 +348,11 @@ void *Wct(void *argument);
 #define  SetgridOperators       {"setgrid", "setgridtype", "setgridarea"}
 #define  SethaloOperators       {"sethalo", "tpnhalo"}
 #define  SetmissOperators       {"setmissval", "setctomiss", "setmisstoc", "setrtomiss", "setvrange"}
-#define  SetrangeOperators      {"setrtoc", "setrtoc2"}
 #define  SetrcanameOperators    {"setrcaname"}
 #define  SettimeOperators       {"setyear", "setmon", "setday", "setdate", "settime", "settunits", \
                                  "settaxis", "setreftime", "setcalendar", "shifttime"}
 #define  SetzaxisOperators      {"setzaxis"}
+#define  ScatterOperators       {"scatter"}
 #define  ShowinfoOperators      {"showyear", "showmon", "showdate", "showtime", "showtimestamp", "showcode", \
                                  "showparam", "showname", "showstdname", "showlevel", "showltype", "showformat"}
 #define  SinfoOperators         {"sinfo", "sinfov", "sinfop"}
@@ -477,12 +485,14 @@ static modules_t Modules[] =
   { Change,         ChangeHelp,        ChangeOperators,        CDI_REAL,  1,  1 },
   { Change_e5slm,   NULL,              Change_e5slmOperators,  CDI_REAL,  1,  1 },
   { Cloudlayer,     NULL,              CloudlayerOperators,    CDI_REAL,  1,  1 },
+  { Command,        NULL,              CommandOperators,       CDI_REAL,  1,  0 },
   { Comp,           CompHelp,          CompOperators,          CDI_REAL,  2,  1 },
   { Compc,          CompcHelp,         CompcOperators,         CDI_REAL,  1,  1 },
+  { Complextorect,  NULL,              ComplextorectOperators, CDI_COMP,  1,  2 },
   { Cond,           CondHelp,          CondOperators,          CDI_REAL,  2,  1 },
   { Cond2,          Cond2Help,         Cond2Operators,         CDI_REAL,  3,  1 },
   { Condc,          CondcHelp,         CondcOperators,         CDI_REAL,  1,  1 },
-  { Complextorect,  NULL,              ComplextorectOperators, CDI_COMP,  1,  2 },
+  { Consecstat,     ConsecstatHelp,    ConsecstatOperators,    CDI_REAL,  1,  1 },
   { Copy,           CopyHelp,          CopyOperators,          CDI_REAL, -1,  1 },
   { Deltime,        NULL,              DeltimeOperators,       CDI_REAL,  1,  1 },
   { Detrend,        DetrendHelp,       DetrendOperators,       CDI_REAL,  1,  1 },
@@ -491,8 +501,8 @@ static modules_t Modules[] =
   { Enlarge,        EnlargeHelp,       EnlargeOperators,       CDI_REAL,  1,  1 },
   { Enlargegrid,    NULL,              EnlargegridOperators,   CDI_REAL,  1,  1 },
   { Ensstat,        EnsstatHelp,       EnsstatOperators,       CDI_REAL, -1,  1 },
-  { Eofcoeff,       NULL,              EofcoeffOperators,      CDI_REAL,  2,  1 },
-  { Timeof,         NULL,              TimeofOperators,        CDI_REAL,  1,  2 },
+  { Eofcoeff,       EofcoeffHelp,      EofcoeffOperators,      CDI_REAL,  2,  1 },
+  { EOFs,           EOFsHelp,          EOFsOperators,          CDI_REAL,  1,  2 },
   { Expr,           ExprHelp,          ExprOperators,          CDI_REAL,  1,  1 },
   { Filedes,        FiledesHelp,       FiledesOperators,       CDI_BOTH,  1,  0 },
   { Fillmiss,       NULL,              FillmissOperators,      CDI_REAL,  1,  1 },
@@ -501,6 +511,7 @@ static modules_t Modules[] =
   { Fldstat,        FldstatHelp,       FldstatOperators,       CDI_REAL,  1,  1 },
   { Fldstat2,       FldcorHelp,        Fldstat2Operators,      CDI_REAL,  2,  1 },
   { Fourier,        NULL,              FourierOperators,       CDI_COMP,  1,  1 },
+  { Gather,         NULL,              GatherOperators,        CDI_REAL, -1,  1 },
   { Gengrid,        NULL,              GengridOperators,       CDI_REAL,  2,  1 },
   { Gradsdes,       GradsdesHelp,      GradsdesOperators,      CDI_REAL,  1,  0 },
   { Gridboxstat,    GridboxstatHelp,   GridboxstatOperators,   CDI_REAL,  1,  1 },
@@ -545,6 +556,7 @@ static modules_t Modules[] =
   { Remap,          GenweightsHelp,    GenweightsOperators,    CDI_REAL,  1,  1 },
   { Remapeta,       RemapetaHelp,      RemapetaOperators,      CDI_REAL,  1,  1 },
   { Replace,        ReplaceHelp,       ReplaceOperators,       CDI_REAL,  2,  1 },
+  { Replacevalues,  ReplacevaluesHelp, ReplacevaluesOperators, CDI_REAL,  1,  1 },
   { Rotuv,          RotuvHelp,         RotuvOperators,         CDI_REAL,  1,  1 },
   { Runpctl,        RunpctlHelp,       RunpctlOperators,       CDI_REAL,  1,  1 },
   { Runstat,        RunstatHelp,       RunstatOperators,       CDI_REAL,  1,  1 },
@@ -562,11 +574,11 @@ static modules_t Modules[] =
   { Setgatt,        SetgattHelp,       SetgattOperators,       CDI_REAL,  1,  1 },
   { Setgrid,        SetgridHelp,       SetgridOperators,       CDI_REAL,  1,  1 },
   { Sethalo,        SethaloHelp,       SethaloOperators,       CDI_REAL,  1,  1 },
-  { Setrange,       SetrangeHelp,      SetrangeOperators,      CDI_REAL,  1,  1 },
   { Setrcaname,     NULL,              SetrcanameOperators,    CDI_REAL,  1,  1 },
   { Setmiss,        SetmissHelp,       SetmissOperators,       CDI_REAL,  1,  1 },
   { Settime,        SettimeHelp,       SettimeOperators,       CDI_REAL,  1,  1 },
   { Setzaxis,       SetzaxisHelp,      SetzaxisOperators,      CDI_REAL,  1,  1 },
+  { Scatter,        NULL,              ScatterOperators,       CDI_REAL,  1,  1 },
   { Showinfo,       ShowinfoHelp,      ShowinfoOperators,      CDI_BOTH,  1,  0 },
   { Sinfo,          SinfoHelp,         SinfoOperators,         CDI_BOTH, -1,  0 },
   { Smooth9,        Smooth9Help,       Smooth9Operators,       CDI_REAL,  1,  1 },
