@@ -145,16 +145,16 @@ void remapVarsInit(int map_type, remapgrid_t *rg, remapvars_t *rv);
 void remapVarsFree(remapvars_t *rv);
 void remapGridFree(remapgrid_t *rg);
 
-void remap(double * restrict dst_array, double missval, long dst_size, long num_links, double ** restrict map_wts, 
-	   long num_wts, const int * restrict dst_add, const int * restrict src_add, const double * restrict src_array, 
-	   const double * restrict src_grad1, const double * restrict src_grad2, const double * restrict src_grad3,
+void remap(double *restrict dst_array, double missval, long dst_size, long num_links, double *restrict *restrict map_wts, 
+	   long num_wts, const int *restrict dst_add, const int *restrict src_add, const double *restrict src_array, 
+	   const double *restrict src_grad1, const double *restrict src_grad2, const double *restrict src_grad3,
 	   remaplink_t links);
 
-void remap_laf(double * restrict dst_array, double missval, long dst_size, long num_links, double ** restrict map_wts,
-	       const int * restrict dst_add, const int * restrict src_add, const double * restrict src_array);
+void remap_laf(double *restrict dst_array, double missval, long dst_size, long num_links, double *restrict *restrict map_wts,
+	       const int *restrict dst_add, const int *restrict src_add, const double *restrict src_array);
 
-void remap_sum(double * restrict dst_array, double missval, long dst_size, long num_links, double ** restrict map_wts,
-	       const int * restrict dst_add, const int * restrict src_add, const double * restrict src_array);
+void remap_sum(double *restrict dst_array, double missval, long dst_size, long num_links, double *restrict *restrict map_wts,
+	       const int *restrict dst_add, const int *restrict src_add, const double *restrict src_array);
 
 void remap_bilin(remapgrid_t *rg, remapvars_t *rv);
 void remap_bicub(remapgrid_t *rg, remapvars_t *rv);
@@ -164,14 +164,15 @@ void remap_distwgt1(remapgrid_t *rg, remapvars_t *rv);
 
 void resize_remap_vars(remapvars_t *rv, int increment);
 
-void remap_stat(int remap_order, remapgrid_t rg, remapvars_t rv, const double * restrict array1, 
-		const double * restrict array2, double missval);
-void remap_gradients(remapgrid_t rg, const double * restrict array, double * restrict grad1_lat,
-		     double * restrict grad1_lon, double * restrict grad1_latlon);
+void remap_stat(int remap_order, remapgrid_t rg, remapvars_t rv, const double *restrict array1, 
+		const double *restrict array2, double missval);
+void remap_gradients(remapgrid_t rg, const double *restrict array, double *restrict grad1_lat,
+		     double *restrict grad1_lon, double *restrict grad1_latlon);
 
 void reorder_links(remapvars_t *rv);
 
-void sort_add(long num_links, long num_wts, int * restrict add1, int * restrict add2, double ** restrict weights);
+void sort_add(long num_links, long num_wts, int *restrict add1, int *restrict add2, double *restrict *restrict weights);
+void sort_add_test(long num_links, long num_wts, int *restrict add1, int *restrict add2, double *restrict *restrict weights);
 
 void write_remap_scrip(const char *interp_file, int map_type, int submap_type, 
 		       int remap_order, remapgrid_t rg, remapvars_t rv);
